function [a0, a1, a2, b0, b1, b2] = iirfilter_eapo(ftype, dbGain, freq, srate, bandwidthOrQOrS, partype) % isBandwidth, isCornerFreq)

    if strcmp(partype,'BW')
        isBandwidth = true;
    else
        isBandwidth = false;
    end
    
    if strcmp(partype,'CF')
        isCornerFreq = true;
    else
        isCornerFreq = false;
    end
        

	if (strcmp(ftype,'PEAKING') || strcmp(ftype,'LOW_SHELF') || strcmp(ftype,'HIGH_SHELF'))
		A = 10^(dbGain / 40);
	else
		A = 10^(dbGain / 20);
    end
	omega = 2 * pi * freq / srate;
	sn = sin(omega);
	cs = cos(omega);
	beta = -1;

	if (strcmp(ftype,'LOW_SHELF') || strcmp(ftype,'HIGH_SHELF'))
		alpha = sn / 2 * sqrt((A + 1 / A) * (1 / (bandwidthOrQOrS/12) - 1) + 2);
		beta = 2 * sqrt(A) * alpha;
    elseif (isBandwidth)
		alpha = sn * sinh(log(2) / 2 * bandwidthOrQOrS * omega / sn);
    else
		alpha = sn / (2 * bandwidthOrQOrS);
    end
    
	if (isCornerFreq && (strcmp(ftype,'LOW_SHELF') || strcmp(ftype,'HIGH_SHELF')))
  		% frequency adjustment for DCX2496
        centerFreqFactor = (10^(abs(dbGain)/80.0/bandwidthOrQOrS));
  		if (strcmp(ftype,'LOW_SHELF'))
  			freq = freq*centerFreqFactor;
  		else
 			freq = freq/centerFreqFactor;
        end
    end
    
	switch ftype
	case 'LOW_PASS'
		b0 = (1 - cs) / 2;
		b1 = 1 - cs;
		b2 = (1 - cs) / 2;
		a0 = 1 + alpha;
		a1 = -2 * cs;
		a2 = 1 - alpha;
	case 'HIGH_PASS'
		b0 = (1 + cs) / 2;
		b1 = -(1 + cs);
		b2 = (1 + cs) / 2;
		a0 = 1 + alpha;
		a1 = -2 * cs;
		a2 = 1 - alpha;
	case 'BAND_PASS'
		b0 = alpha;
		b1 = 0;
		b2 = -alpha;
		a0 = 1 + alpha;
		a1 = -2 * cs;
		a2 = 1 - alpha;
	case 'NOTCH'
		b0 = 1;
		b1 = -2 * cs;
		b2 = 1;
		a0 = 1 + alpha;
		a1 = -2 * cs;
		a2 = 1 - alpha;
	case 'ALL_PASS'
		b0 = 1 - alpha;
		b1 = -2 * cs;
		b2 = 1 + alpha;
		a0 = 1 + alpha;
		a1 = -2 * cs;
		a2 = 1 - alpha;
	case 'PEAKING'
		b0 = 1 + (alpha * A);
		b1 = -2 * cs;
		b2 = 1 - (alpha * A);
		a0 = 1 + (alpha / A);
		a1 = -2 * cs;
		a2 = 1 - (alpha / A);

	case 'LOW_SHELF'
		b0 = A * ((A + 1) - (A - 1) * cs + beta);
		b1 = 2 * A * ((A - 1) - (A + 1) * cs);
		b2 = A * ((A + 1) - (A - 1) * cs - beta);
		a0 = (A + 1) + (A - 1) * cs + beta;
		a1 = -2 * ((A - 1) + (A + 1) * cs);
		a2 = (A + 1) + (A - 1) * cs - beta;

	case 'HIGH_SHELF'
		b0 = A * ((A + 1) + (A - 1) * cs + beta);
		b1 = -2 * A * ((A - 1) + (A + 1) * cs);
		b2 = A * ((A + 1) + (A - 1) * cs - beta);
		a0 = (A + 1) - (A - 1) * cs + beta;
		a1 = 2 * ((A - 1) - (A + 1) * cs);
		a2 = (A + 1) - (A - 1) * cs - beta;
        
    end
    
end
